Documentation
¶
Overview ¶
Package server implements the entry point for running a robot web server.
Package server implements the entry point for running a robot web server.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ForceRestart bool
ForceRestart lets random other parts of the app request an exit.
Functions ¶
Types ¶
type Arguments ¶
type Arguments struct {
AllowInsecureCreds bool `flag:"allow-insecure-creds,usage=allow connections to send credentials over plaintext"`
ConfigFile string `flag:"config,usage=robot config file"`
CPUProfile string `flag:"cpuprofile,usage=write cpu profile to file"`
Debug bool `flag:"debug"`
Logging bool `flag:"logging,default=false,usage=emit periodic resource status information to Viam's hidden folder"`
Version bool `flag:"version,usage=print version"`
WebProfile bool `flag:"webprofile,usage=include profiler in http server"`
WebRTC bool `flag:"webrtc,default=true,usage=force webrtc connections instead of direct"`
RevealSensitiveConfigDiffs bool `flag:"reveal-sensitive-config-diffs,usage=show config diffs"`
UntrustedEnv bool `flag:"untrusted-env,usage=disable processes and shell from running in a untrusted environment"`
OutputTelemetry bool `flag:"output-telemetry,usage=print out telemetry data (metrics and spans)"`
DisableMulticastDNS bool `flag:"disable-mdns,usage=disable server discovery through multicast DNS"`
DumpResourcesPath string `flag:"dump-resources,usage=dump all resource registrations as json to the provided file path"`
}
Arguments for the command.
Click to show internal directories.
Click to hide internal directories.